| Title: | Color Palettes Inspired by Paris 2024 Olympic and Paralympic Games |
|---|---|
| Description: | Palettes inspired by Paris 2024 Olympic and Paralympic Games for data visualizations. Length of color palettes is configurable. |
| Authors: | Maxime Kuntz [aut, cre] (ORCID: <https://orcid.org/0000-0002-2068-904X>) |
| Maintainer: | Maxime Kuntz <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.0.9000 |
| Built: | 2026-05-13 06:08:36 UTC |
| Source: | https://github.com/maximekuntz/paris2024colours |
Paris 2024 palette generator
paris2024_palette(name, n, type = c("discrete", "continuous"), reverse = FALSE)paris2024_palette(name, n, type = c("discrete", "continuous"), reverse = FALSE)
name |
Name of the colour palette. Options are |
n |
Number of colours in the palette. Palettes have 2 to 5 colours that can be used as a discrete palette. To use more, use a continuous palette. |
type |
Usage of palette as "continuous" or "discrete". Continuous usage interpolates between colors to create a scale of values. If omitted, function assumes continuous if n > length of palette, and discrete if n < length of palette. |
reverse |
Whether to reverse colour palette (TRUE) or not (FALSE, default). |
A vector of colours.
paris2024_palette("GamesLook", n = 6, type = "continuous") paris2024_palette("Logo", 2) paris2024_palette("OlympicRings") paris2024_palette("OlympicRings", reverse = TRUE)paris2024_palette("GamesLook", n = 6, type = "continuous") paris2024_palette("Logo", 2) paris2024_palette("OlympicRings") paris2024_palette("OlympicRings", reverse = TRUE)
Use paris2024_palette to construct palettes of desired length.
paris2024_palettesparis2024_palettes
An object of class list of length 9.
Palette printer
## S3 method for class 'palette' print(x, ...)## S3 method for class 'palette' print(x, ...)
x |
A palette |
... |
... |
An image of the palette
Function for using Paris2024Colours colours schemes in ggplot2.
scale_colour_paris2024(type = c("discrete", "continuous"), ...) scale_color_paris2024(type = c("discrete", "continuous"), ...)scale_colour_paris2024(type = c("discrete", "continuous"), ...) scale_color_paris2024(type = c("discrete", "continuous"), ...)
type |
Usage of palette as "continuous" or "discrete". Continuous usage interpolates between colours to create a scale of values. |
... |
Other arguments passed on to
|
A function that returns a colour scale.
Function for using Paris2024Colours colours schemes in ggplot2.
Use scale_colour_paris2024_d and
scale_fill_paris2024_d for discrete scales, and use
scale_colour_paris2024_c and
scale_fill_paris2024_c for continuous scales.
scale_colour_paris2024_c(name, reverse = FALSE, ...) scale_color_paris2024_c(name, reverse = FALSE, ...)scale_colour_paris2024_c(name, reverse = FALSE, ...) scale_color_paris2024_c(name, reverse = FALSE, ...)
name |
Name of the colour palette. Options are |
reverse |
Whether to reverse colour palette (TRUE) or not (FALSE, default). |
... |
Other arguments passed on to
|
A function that returns a continuous colour scale.
library(ggplot2) ggplot2::ggplot( data = iris, aes(x = Sepal.Width, y = Sepal.Length, colour = Sepal.Length) ) + geom_point() + scale_colour_paris2024_c("GamesLook")library(ggplot2) ggplot2::ggplot( data = iris, aes(x = Sepal.Width, y = Sepal.Length, colour = Sepal.Length) ) + geom_point() + scale_colour_paris2024_c("GamesLook")
Function for using Paris2024Colours colours schemes in ggplot2.
Use scale_colour_paris2024_d and
scale_fill_paris2024_d for discrete scales, and use
scale_colour_paris2024_c and
scale_fill_paris2024_c for continuous scales.
scale_colour_paris2024_d(name, reverse = FALSE, ...) scale_color_paris2024_d(name, reverse = FALSE, ...)scale_colour_paris2024_d(name, reverse = FALSE, ...) scale_color_paris2024_d(name, reverse = FALSE, ...)
name |
Name of the colour palette. Options are |
reverse |
Whether to reverse colour palette (TRUE) or not (FALSE, default). |
... |
Other arguments passed on to |
A function that returns a discrete colour scale.
library(ggplot2) ggplot2::ggplot( data = iris, aes(x = Sepal.Width, y = Sepal.Length, colour = Species) ) + geom_point() + scale_colour_paris2024_d("GamesLook")library(ggplot2) ggplot2::ggplot( data = iris, aes(x = Sepal.Width, y = Sepal.Length, colour = Species) ) + geom_point() + scale_colour_paris2024_d("GamesLook")
Function for using Paris2024Colours colours schemes in ggplot2.
scale_fill_paris2024(type = c("discrete", "continuous"), ...)scale_fill_paris2024(type = c("discrete", "continuous"), ...)
type |
Usage of palette as "continuous" or "discrete". Continuous usage interpolates between colours to create a scale of values. |
... |
Other arguments passed on to |
A function that returns a colour scale.
Function for using Paris2024Colours colours schemes in ggplot2.
Use scale_colour_paris2024_d and
scale_fill_paris2024_d for discrete scales, and use
scale_colour_paris2024_c and
scale_fill_paris2024_c for continuous scales.
scale_fill_paris2024_c(name, reverse = FALSE, ...)scale_fill_paris2024_c(name, reverse = FALSE, ...)
name |
Name of the colour palette. Options are |
reverse |
Whether to reverse colour palette (TRUE) or not (FALSE, default). |
... |
Other arguments passed on to
|
A function that returns a continuous colour scale.
Function for using Paris2024Colours colours schemes in ggplot2.
Use scale_colour_paris2024_d and
scale_fill_paris2024_d for discrete scales, and use
scale_colour_paris2024_c and
scale_fill_paris2024_c for continuous scales.
scale_fill_paris2024_d(name, reverse = FALSE, ...)scale_fill_paris2024_d(name, reverse = FALSE, ...)
name |
Name of the colour palette. Options are |
reverse |
Whether to reverse colour palette (TRUE) or not (FALSE, default). |
... |
Other arguments passed on to |
A function that returns a discrete colour scale.
library(ggplot2) ggplot2::ggplot( data = iris, aes(x = Species, y = Sepal.Length, fill = Species) ) + geom_violin() + scale_fill_paris2024_d("GamesLook")library(ggplot2) ggplot2::ggplot( data = iris, aes(x = Species, y = Sepal.Length, fill = Species) ) + geom_violin() + scale_fill_paris2024_d("GamesLook")